#include <Application.h>
#include <Window.h>
#include <View.h>
#include <Bitmap.h>
#include <String.h>
#include <Entry.h>
#include <Path.h>
#include <TranslationUtils.h>

#include "bitmap_utils.h"

class BitmapView : public BView
{
public:
	BitmapView( BRect r )
		: BView( r, "", B_FOLLOW_ALL, B_WILL_DRAW|B_FRAME_EVENTS )
		, bitmap(NULL)
		, orig(NULL)
	{
	}

	virtual void Draw( BRect rect )
	{
		if( bitmap )
		{
			SetDrawingMode( B_OP_ALPHA );
			SetBlendingMode( B_PIXEL_ALPHA, B_ALPHA_OVERLAY );
			DrawBitmap( bitmap, bitmap->Bounds(), Bounds() );
		}
	}

	virtual void FrameResized( float x, float y )
	{
		Render();
	}

	void Render()
	{
		if( orig )
		{
			delete bitmap;
			bitmap = new BBitmap( BRect( 0, 0, Bounds().Width()-1, Bounds().Height() -1 ), B_RGBA32 );
			ScaleBitmap(*orig, *bitmap);
			Invalidate();
		}
	}

	virtual void MessageReceived(BMessage* Message)
	{
		static	entry_ref drop;
		static	BEntry entry;
		static	BPath path;
	
		switch( Message->what )
		{
			case B_SIMPLE_DATA:
			case B_REFS_RECEIVED:
				Message->FindRef("refs", &drop);
				entry.SetTo(&drop);
				entry.GetPath(&path);
				Load(path.Path());
				Render();
				break;
										
			default:
				BView::MessageReceived(Message);
				break;
		}
	}

	void Load(const char* Path)
	{
		delete orig;
		orig = BTranslationUtils::GetBitmap(Path);
	}
	
	BBitmap *bitmap, *orig;
};

class SVGApp : public BApplication
{
	public:
		SVGApp()
			:BApplication( "application/x-vnd.scaling-test" )
		{
			BWindow *window = new BWindow( BRect( 100, 100, 300, 300 ), "scaling test", B_TITLED_WINDOW, B_OUTLINE_RESIZE|B_QUIT_ON_WINDOW_CLOSE );
			BView *backView = new BView(window->Bounds(), "", B_FOLLOW_ALL, 0 );
			window->AddChild(backView);
		
			fView = new BitmapView( window -> Bounds()  );
			fView->SetViewColor( 51, 102, 152 );
			backView->AddChild( fView );
		}
			
		team_id Run()
		{
			WindowAt(0)->Show();
			
			return BApplication::Run();
		}
			
		virtual void RefsReceived(BMessage* Message)
		{
			Message->PrintToStream();
			BMessenger(fView).SendMessage(Message);
		}
		
	BitmapView *fView;

};

int main( int argc, char **argv )
{
	SVGApp app;

	return app.Run();
}

